@@ -6,11 +6,11 @@ Geo::Coder::List - Provide lots of backends for HTML::GoogleMaps::V3
 
 =head1 VERSION
 
-Version 0.01
+Version 0.02
 
 =cut
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 =head1 SYNOPSIS
 
@@ -77,12 +77,30 @@ sub geocode {
 	}
 
 	foreach my $geocoder(@{$self->{geocoders}}) {
-		my @rc = $geocoder->geocode(%params);
+		my @rc;
+		eval {
+			# e.g. over QUERY LIMIT with this one
+			# TODO: remove from the list of geocoders
+			@rc = $geocoder->geocode(%params);
+		};
+		next if $@;
 		foreach my $location(@rc) {
 			# Add HTML::GoogleMaps::V3 compatability
 			unless($location->{geometry}{location}{lat}) {
-				$location->{geometry}{location}{lat} = $location->{lat};
-				$location->{geometry}{location}{lng} = $location->{lon};
+				if($location->{lat}) {
+					# OSM
+					$location->{geometry}{location}{lat} = $location->{lat};
+					$location->{geometry}{location}{lng} = $location->{lon};
+				} elsif($location->{BestLocation}) {
+					# Bing
+					$location->{geometry}{location}{lat} = $location->{BestLocation}->{Coordinates}->{Latitude};
+					$location->{geometry}{location}{lng} = $location->{BestLocation}->{Coordinates}->{Longitude};
+				} elsif($location->{point}) {
+					# Bing
+					$location->{geometry}{location}{lat} = $location->{point}->{coordinates}[0];
+					$location->{geometry}{location}{lng} = $location->{point}->{coordinates}[1];
+				}
+
 			}
 		}
 		if(scalar(@rc)) {
